@@ -11,7 +11,6 @@ from cloudevents.sdk import marshaller
 from cloudevents.sdk.converters import binary
 from cloudevents.sdk.event import v1
 import os
-from django.conf import settings
 
 
 def _get_event_type_from_signal(signal):
@@ -45,15 +44,35 @@ def _get_instance_dict(instance):
             for rel in getattr(instance, field_name).all():
                 instance_dict[field_name].append(_get_instance_dict(rel))
         else:
-            instance_dict[field_name] = str(getattr(instance, field_name))
+            instance_dict[field_name] = getattr(instance, field_name)
     return instance_dict
 
 
+def _handle_cloudevent(event):
+
+    from django.conf import settings
+    cb = settings.CLOUDEVENTS_HANDLER
+    if cb is not None:
+        if callable(cb):
+            cb(event)
+        elif isinstance(cb, str):
+            import importlib
+            mod_name, func_name = cb.rsplit('.', 1)
+            mod = importlib.import_module(mod_name)
+            func = getattr(mod, func_name)
+            func(event)
+
+
 def send_cloudevent(sender, **kwargs):
+
+    event = get_cloudevent_from_signal(sender, **kwargs)
+    _handle_cloudevent(event)
+
+
+def default_handler(event):
+    from django.conf import settings
     sink_url = os.environ.get(settings.CLOUDEVENTS_ENV["SINK_VAR"])
     if sink_url is not None:
-        event = get_cloudevent_from_signal(sender, **kwargs)
-
         m = marshaller.NewHTTPMarshaller([binary.NewBinaryHTTPCloudEventConverter()])
         headers, body = m.ToRequest(event, converters.TypeBinary, json.dumps)
 
@@ -65,6 +84,8 @@ def send_cloudevent(sender, **kwargs):
 
 
 def get_cloudevent_from_signal(sender, **kwargs):
+
+    from django.conf import settings
     event_type = _get_event_type_from_signal(kwargs.pop("signal"))
     obj_meta = sender._meta
     app = obj_meta.app_label
@@ -88,7 +109,7 @@ def get_cloudevent_from_signal(sender, **kwargs):
             payload["data"][field_name] = m2m_data
         # TODO parse related_fields
         # for r_field in obj_meta.related_objects:
-        subject = "DCE:%s.%s/%s" % (app, model, instance.id)
+        subject = "DCE:%s.%s/%s" % (app, model, instance.pk)
     else:
         subject = "DCE:%s.%s" % (app, model)
     payload["signal_kwargs"] = {
